****************
probnum.problems
****************

.. automodapi:: probnum.problems
    :no-heading:
    :headings: "="
    :no-inheritance-diagram:

probnum.problems.zoo
====================

Subpackage offering implementations of standard example problems or convenient
interfaces to benchmark problems for probabilistic numerical methods. These test
problems are meant for rapid experimentation and prototyping.

probnum.problems.zoo.diffeq
---------------------------

.. automodapi:: probnum.problems.zoo.diffeq
    :no-heading:

probnum.problems.zoo.filtsmooth
-------------------------------

.. automodapi:: probnum.problems.zoo.filtsmooth
    :no-heading:

probnum.problems.zoo.linalg
---------------------------

.. automodapi:: probnum.problems.zoo.linalg
    :no-heading:
